@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: io.h,v 1.46 1999/10/11 20:57:53 nisse Exp $ */
+ * $Id: io.h,v 1.48 1999/11/03 19:20:54 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -313,8 +313,10 @@ struct address_info *sockaddr2info(size_t addr_len UNUSED,
 int address_info2sockaddr_in(struct sockaddr_in *sin,
 			     struct address_info *a);
 
-void write_raw(int fd, UINT32 length, UINT8 *data, struct exception_handler *e);
-void write_raw_with_poll(int fd, UINT32 length, UINT8 *data, struct exception_handler *e);
+void write_raw(int fd, UINT32 length, const UINT8 *data,
+	       struct exception_handler *e);
+void write_raw_with_poll(int fd, UINT32 length, const UINT8 *data,
+			 struct exception_handler *e);
 
 void io_set_nonblocking(int fd);
 void io_set_close_on_exec(int fd);
@@ -336,9 +338,11 @@ io_connect(struct io_backend *b,
 	   struct fd_callback *f,
 	   struct exception_handler *e);
 
-struct listen_fd *io_listen(struct io_backend *b,
-			    struct sockaddr_in *local,
-			    struct fd_listen_callback *callback);
+struct listen_fd *
+io_listen(struct io_backend *b,
+	  struct sockaddr_in *local,
+	  struct fd_listen_callback *callback,
+	  struct exception_handler *e);
 
 struct io_fd *io_read_write(struct io_fd *fd,
 			    struct io_read_callback *read,
