@@ -2,7 +2,7 @@
  *
  * client main program
  *
- * $Id: lsh.c,v 1.77 1999/10/13 16:02:20 nisse Exp $ */
+ * $Id: lsh.c,v 1.81 1999/11/07 20:14:06 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -41,6 +41,7 @@
 #include "randomness.h"
 #include "service.h"
 #include "ssh.h"
+#include "spki.h"
 #include "tcpforward_commands.h"
 #include "tty.h"
 #include "userauth.h"
@@ -212,6 +213,7 @@ static int remember_tty(int fd)
 /* Option parsing */
 
 #define ARG_NOT 0x200
+#define OPT_NO_PUBLICKEY 0x201
 
 static const struct argp_option
 main_options[] =
@@ -219,10 +221,13 @@ main_options[] =
   /* Name, key, arg-name, flags, doc, group */
   { "port", 'p', "Port", 0, "Connect to this port.", 0 },
   { "user", 'l', "User name", 0, "Login as this user.", 0 },
+  { "identity", 'i',  "Identity key", 0, "Use this key to authenticate.", 0 },
+  { "no-publickey", OPT_NO_PUBLICKEY, NULL, 0,
+    "Don't try publickey user authentication.", 0 },
   { NULL, 0, NULL, 0, "Actions:", 0 },
   { "forward-local-port", 'L', "local-port:target-host:target-port", 0, "", 0 },
   { "forward-remote-port", 'R', "remote-port:target-host:target-port", 0, "", 0 },
-  { "nop", 'N', NULL, 0, "No operation (supresses the default action, "
+  { "nop", 'N', NULL, 0, "No operation (suppresses the default action, "
     "which is to spawn a remote shell)", 0 },
   { NULL, 0, NULL, 0, "Modifiers that apply to port forwarding:", 0 },
   { "remote-peers", 'g', NULL, 0, "Allow remote access to forwarded ports", 0 },
@@ -244,6 +249,7 @@ main_options[] =
      (super algorithms_options)
      (vars
        (backend object io_backend)
+       (random object randomness)
 
        ; For i/o exceptions 
        (handler object exception_handler)
@@ -255,7 +261,8 @@ main_options[] =
        (remote object address_info)
 
        (user . "char *")
-
+       (identities struct object_queue)
+       (publickey . int)
        ; -1 means default behaviour
        (with_pty . int)
 
@@ -268,6 +275,7 @@ main_options[] =
 
 static struct lsh_options *
 make_options(struct alist *algorithms, struct io_backend *backend,
+	     struct randomness *random,
 	     struct exception_handler *handler,
 	     int *exit_code)
 {
@@ -276,6 +284,7 @@ make_options(struct alist *algorithms, struct io_backend *backend,
   init_algorithms_options(&self->super, algorithms);
   
   self->backend = backend;
+  self->random = random;
   self->handler = handler;
   self->exit_code = exit_code;
   
@@ -288,6 +297,9 @@ make_options(struct alist *algorithms, struct io_backend *backend,
   self->start_shell = 1;
   self->with_remote_peers = 0;
   object_queue_init(&self->actions);
+  object_queue_init(&self->identities);
+
+  self->publickey = 1;
   
   return self;
 }
@@ -426,6 +438,23 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
 	  break;
 	}
 
+      if (self->publickey && object_queue_is_empty(&self->identities))
+	{
+	  char *home = getenv("HOME");
+	  if (home)
+	    {
+	      struct lsh_string *idfile = 
+		ssh_format("%lz/.lsh/identity%c", home, 0);
+	      struct keypair *id;
+	      if ((id = read_spki_key_file(idfile->data, self->random, self->handler)))
+		{
+		  verbose("Adding identity %S\n", idfile);
+		  object_queue_add_tail(&self->identities, &id->super);
+		}
+	      lsh_string_free(idfile);
+	    }
+	}
+      
       break;
       
     case 'p':
@@ -434,6 +463,19 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
     case 'l':
       self->user = arg;
       break;
+    case 'i':
+      {
+	struct keypair *id;
+	if ((id = read_spki_key_file(arg, self->random, self->handler)))
+	  {
+	    verbose("Adding identity %s\n", arg);
+	    object_queue_add_tail(&self->identities, &id->super);
+	  }
+	break;
+      }
+    case OPT_NO_PUBLICKEY:
+      self->publickey = 0;
+      break;
       
     case 'L':
       {
@@ -553,8 +595,10 @@ do_lsh_default_handler(struct exception_handler *s,
 #endif
 	default:
 	  *self->status = EXIT_FAILURE;
+#if 0
 	  EXCEPTION_RAISE(self->super.parent, e);
 	  return;
+#endif
 	}
       werror("lsh: %z, (errno = %i)\n", e->msg, exc->error);
     }
@@ -624,10 +668,6 @@ int main(int argc, char **argv)
 
   /* No randomness is needed for verifying signatures */
   lookup_table = make_alist(1
-#if DATAFELLOWS_WORKAROUNDS
-			    +1,
-			    ATOM_SSH_DSS_KLUDGE, make_fake_host_db(make_dsa_kludge_algorithm(NULL))
-#endif
 			    , ATOM_SSH_DSS, make_fake_host_db(make_dsa_algorithm(NULL)),
 			    -1); 
 
@@ -638,7 +678,7 @@ int main(int argc, char **argv)
 			       -1);
 
 
-  options = make_options(algorithms, backend, handler, &lsh_exit_code);
+  options = make_options(algorithms, backend, r, handler, &lsh_exit_code);
 
   argp_parse(&main_argp, argc, argv, ARGP_IN_ORDER, NULL, options);
   
@@ -662,8 +702,17 @@ int main(int argc, char **argv)
 						 make_kexinit,
 						 NULL),
 			  make_request_service(ATOM_SSH_USERAUTH),
-			  make_client_userauth(ssh_format("%lz", options->user),
-					       ATOM_SSH_CONNECTION),
+			  make_client_userauth(
+			    ssh_format("%lz", options->user),
+			    ATOM_SSH_CONNECTION,
+			    /* FIXME: Move this logic into the option parser. */
+			    (object_queue_is_empty(&options->identities)
+			     ? make_object_list(1, make_client_password_auth(), 
+						-1)
+			     : make_object_list(2, 
+						make_client_publickey_auth(queue_to_list(&options->identities)),
+						make_client_password_auth(), 
+						-1))),
 			  queue_to_list(&options->actions));
     
     CAST_SUBTYPE(command, client_connect, o);
