@@ -2,7 +2,7 @@
  *
  * Reads a (private) key on stdin, and saves it a private and a public file.
  *
- * $Id: lsh_writekey.c,v 1.14 1999/09/20 22:09:23 nisse Exp $ */
+ * $Id: lsh_writekey.c,v 1.15 1999/11/07 21:02:10 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -47,11 +47,11 @@ static struct read_sexp_command read_sexp
 
 #define READ_SEXP (&read_sexp.super.super)
 
-static struct print_sexp_command write_canonical
+static struct sexp_print_command write_canonical
 = STATIC_PRINT_SEXP(SEXP_CANONICAL);
 #define CANONICAL (&write_canonical.super.super.super)
 
-static struct print_sexp_command write_transport
+static struct sexp_print_command write_transport
 = STATIC_PRINT_SEXP(SEXP_TRANSPORT);
 #define TRANSPORT (&write_transport.super.super.super)
 
