@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: publickey_crypto.h,v 1.24 1999/09/22 01:11:39 nisse Exp $ */
+ * $Id: publickey_crypto.h,v 1.26 1999/11/07 00:06:28 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -39,11 +39,15 @@
    (class
      (name keypair)
      (vars
+       ; Atom identifying algorithm type. Needed mostly to know when to invoke the
+       ; ssh2 ssh-dss bug-compatibility kludge. 
+       (type . int)
        (public string)
        (private object signer)))
 */
 
-struct keypair *make_keypair(struct lsh_string *public,
+struct keypair *make_keypair(UINT32 type,
+			     struct lsh_string *public,
 			     struct signer *private);
 
 /* parse an ssh keyblob */
@@ -56,7 +60,7 @@ struct signature_algorithm *make_dsa_algorithm(struct randomness *random);
 #if DATAFELLOWS_WORKAROUNDS
 struct signer *make_dsa_signer_kludge(struct signer *dsa);
 struct verifier *make_dsa_verifier_kludge(struct verifier *v);
-struct signature_algorithm *make_dsa_kludge_algorithm(struct randomness *random);
+/* struct signature_algorithm *make_dsa_kludge_algorithm(struct randomness *random); */
 #endif
 
 struct signer *make_dsa_signer_classic(struct signer *s);
