@@ -2,7 +2,7 @@
  *
  * user authorization database
  *
- * $Id: server_authorization.c,v 1.3 1999/10/19 17:58:27 nisse Exp $ */
+ * $Id: server_authorization.c,v 1.4 1999/11/07 00:08:13 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -79,7 +79,7 @@ static struct verifier *do_key_lookup(struct lookup_verifier *c,
   KILL(h);
   lsh_string_free(pubkey_spki_blob);
   
-  filename = ssh_format("%lS/.lsh/%S/%lxs%c", 
+  filename = ssh_format("%lS/.lsh/%lS/%lxs%c", 
 			user->home,
 			closure->index_name,
 			closure->hashalgo->hash_size, pubkey_spki_hash,
