@@ -32,6 +32,7 @@
 #include "charset.h"
 #include "ssh.h"
 #include "lookup_verifier.h"
+#include "publickey_crypto.h"
 
 #include "server_publickey.c.x"
 
@@ -84,14 +85,8 @@ do_authenticate(struct userauth *s,
 	  && parse_eod(args))
        : parse_eod(args))) 
     {
-#if DATAFELLOWS_WORKAROUNDS
-      if (algorithm == ATOM_SSH_DSS && (connection->peer_flags & PEER_SSH_DSS_KLUDGE))
-	{
-	  lookup = ALIST_GET(self->verifiers, ATOM_SSH_DSS_KLUDGE);
-	}
-      else
-#endif
-	lookup = ALIST_GET(self->verifiers, algorithm);
+
+      lookup = ALIST_GET(self->verifiers, algorithm);
 
       if (!lookup) 
 	{
@@ -107,6 +102,12 @@ do_authenticate(struct userauth *s,
 	}
       v = LOOKUP_VERIFIER(lookup, username, keyblob);
 
+#if DATAFELLOWS_WORKAROUNDS
+      if ( v && (algorithm == ATOM_SSH_DSS)
+	   && (connection->peer_flags & PEER_SSH_DSS_KLUDGE))
+	v = make_dsa_verifier_kludge(v);
+#endif
+
       if (!check_key)
 	{
 	  lsh_string_free(username);
@@ -132,9 +133,8 @@ do_authenticate(struct userauth *s,
       else 
 	{
 	  struct lsh_string *signed_data;
-	  struct unix_user *user = NULL;
+
 #if DATAFELLOWS_WORKAROUNDS
-	  /* FIXME: this check should be made more general */
 	  if (connection->peer_flags & PEER_USERAUTH_REQUEST_KLUDGE)
 	    {
 	      signed_data = ssh_format("%lS%c%S%a%a%c%a%S", 
@@ -159,11 +159,18 @@ do_authenticate(struct userauth *s,
 	  if (VERIFY(v, signed_data->length, signed_data->data, signature_length, signature_blob))
 	    {
 	      werror("user %S has authenticated\n", username);
-	      user = lookup_user(username, 0);
+	      /* FIXME: We should have done this lookup already */
+	      COMMAND_RETURN(c, lookup_user(username, 0));
+	    }
+	  else
+	    {
+              static const struct exception bad_sign
+                = STATIC_EXCEPTION(EXC_USERAUTH, "Bad signature in userauth request");
+	      
+              EXCEPTION_RAISE(e, &bad_sign);
 	    }
 	  lsh_string_free(username);
 	  lsh_string_free(signed_data);
-	  COMMAND_RETURN(c, user);
 	  return;
 	}
     }
