@@ -2,7 +2,7 @@
  *
  * An implementation of SPKI certificate checking
  *
- * $Id: spki.h,v 1.2 1999/09/07 09:23:29 nisse Exp $ */
+ * $Id: spki.h,v 1.4 1999/11/07 20:43:26 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -28,6 +28,7 @@
 
 #include "exception.h"
 #include "sexp.h"
+#include "alist.h"
 
 #define GABA_DECLARE
 #include "spki.h.x"
@@ -54,4 +55,23 @@ struct sexp *keyblob2spki(struct lsh_string *keyblob);
 extern struct command spki_public2private;
 #define PRIVATE2PUBLIC (&spki_public2private.super)
 
+#if 0
+extern struct spki_hash spki_hash_md5;
+#define SPKI_HASH_MD5 (&spki_hash_md5.super.super)
+extern struct spki_hash spki_hash_sha1;
+#define SPKI_HASH_SHA1 (&spki_hash_sha1.super.super)
+#endif
+
+struct command *
+make_spki_hash(int name, struct hash_algorithm *algorithm);
+
+struct command *
+make_spki_parse_key(struct randomness *random);
+
+struct keypair *
+read_spki_key_file(const char *name,
+		   struct randomness *r,
+		   struct exception_handler *e);
+
+
 #endif /* LSH_SPKI_H_INCLUDED */
